package com.xhly.manageapp.viewmodel

import androidx.lifecycle.LiveData
import androidx.lifecycle.MutableLiveData
import com.xhly.corelib.base.viewmodel.CommonBaseViewModel
import com.xhly.corelib.network.RetrofitService
import com.xhly.manageapp.bean.log.LogPushBean
import com.xhly.manageapp.bean.log.LogdOperateBean
import com.xhly.manageapp.network.log.LogService
import com.xhly.manageapp.ui.login.netservice.LoginService

open class BaseViewModel : CommonBaseViewModel() {
    protected val loginService: LoginService by lazy { RetrofitService.create<LoginService>() }
    private val logService: LogService = RetrofitService.create<LogService>()
    private val pwdResult = MutableLiveData<Boolean>()
    val pwdResultData: LiveData<Boolean> = pwdResult
    private val timeResult = MutableLiveData<Long>()
    val timeResultData: LiveData<Long> = timeResult
    private val controlResult = MutableLiveData<Boolean>()
    val controlResultData: LiveData<Boolean> = controlResult
    private val lockResult = MutableLiveData<Boolean>()
    val lockResultData: LiveData<Boolean> = lockResult
    private val resetResult = MutableLiveData<Boolean>()
    val resetlResultData: LiveData<Boolean> = resetResult

    /**
     * 解除当前锁屏
     */
    fun postPwdDetail(code: String, sn: String) {
        launchUI {
            val map = HashMap<String, Any>()
            map["sn"] = sn
            val result = loginService.postPwdDetail(map)
            if (result.code == 0) {
                pwdResult.value = result.obj.controlPwd.equals(code)
            } else {
                pwdResult.value = false
            }
        }
    }

    /**
     * 发送事件日志
     */
    fun eventLog(operateBean: LogdOperateBean) {
        launchUI {
            logService.postLogdoperateAdd(operateBean)
        }
    }

    /**
     * 发送事件推送日志
     */
    fun postLogPushAdd(logPushBean: LogPushBean) {
        launchUI {
            logService.postLogPushAdd(logPushBean)
        }
    }
    /**
     * 同步服务器的时间
     */
    fun postSyncTime(){
        launchUI {
            val startTime = System.currentTimeMillis()
            val postSyncTime = loginService.postSyncTime()
            if (postSyncTime.code==0){
                val endTime = System.currentTimeMillis()
                val obj = postSyncTime.obj
                timeResult.value=obj+(endTime-startTime)/2
            }else{
                if (!postSyncTime.msg.isNullOrEmpty()){
                   netMessage.value=postSyncTime.msg
                }
            }
        }
    }
    /**
     * 手动退出管控
     */
    fun postExitControl(password:String){
        launchUI {
            val map=HashMap<String,Any>()
            map["password"]=password
            val result= loginService.postExitControl(map)
            if (result.code==0){
                val codeDetailBean = result.obj
                controlResult.value = password==codeDetailBean.controlPwd
            }else{
                if (!result.msg.isNullOrEmpty()){
                    netMessage.value=result.msg
                }
            }
        }
    }

    /**
     * 违规事件发送socket消息后，请求接口然后处理锁定
     * sn 设备号
     *  pushType  3锁定
     */
    fun postExitLocked(sn:String,pushType:Int=3){
        launchUI {
            val map=HashMap<String,Any>()
            map["sn"]=sn
            map["pushType"]=pushType
            val result = loginService.postExitLocked(map)
            if (result.code==0){
                lockResult.value=true
            }else{
                if (!result.msg.isNullOrEmpty()){
                    netMessage.value=result.msg
                }
            }
        }
    }

    /**
     * 违规事件发送socket消息后，请求接口然后处理恢复出厂设置
     * sn 设备号
     * pushType  6恢复出厂设置
     */
    fun postExitReseted(sn:String,pushType:Int=6){
        launchUI {
            val map=HashMap<String,Any>()
            map["sn"]=sn
            map["pushType"]=pushType
            val result = loginService.postExitReseted(map)
            if (result.code==0){
                resetResult.value=true
            }else{
                if (!result.msg.isNullOrEmpty()){
                    netMessage.value=result.msg
                }
            }
        }
    }
}